@@ -1,22 +1,21 @@
-/*
- *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- */
+///
+///  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///
+///  This program is free software; you can redistribute it and/or modify
+///  it under the terms of the GNU General Public License as published by
+///  the Free Software Foundation; either version 2 of the License, or
+///  (at your option) any later version.
+///
+///  This program is distributed in the hope that it will be useful,
+///  but WITHOUT ANY WARRANTY; without even the implied warranty of
+///  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+///  GNU General Public License for more details.
+///
+///
+///  You should have received a copy of the GNU General Public License
+///  along with this program; if not, write to the Free Software
+///  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+///
 
 #include "AbsCell.h"
 #include "TextCell.h"
@@ -41,9 +40,9 @@ AbsCell::~AbsCell()
 MathCell* AbsCell::Copy(bool all)
 {
   AbsCell* tmp = new AbsCell;
+  CopyData(this, tmp);
   tmp->SetInner(m_innerCell->Copy(true));
-  tmp->m_type = m_type;
-  if (all && m_next!=NULL)
+  if (all && m_next != NULL)
     tmp->AppendCell(m_next->Copy(all));
   return tmp;
 }
@@ -59,7 +58,7 @@ void AbsCell::Destroy()
 void AbsCell::SetInner(MathCell *inner)
 {
   if (inner == NULL)
-    return;
+    return ;
   if (m_innerCell != NULL)
     delete m_innerCell;
   m_innerCell = inner;
@@ -94,7 +93,8 @@ void AbsCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
 {
   double scale = parser.GetScale();
   wxDC& dc = parser.GetDC();
-  if (DrawThisCell(parser, point)) {
+  if (DrawThisCell(parser, point))
+  {
     SetPen(parser);
     wxPoint in;
     in.x = point.x + SCALE_PX(4, scale);
@@ -128,7 +128,8 @@ void AbsCell::SelectInner(wxRect& rect, MathCell **first, MathCell **last)
   if (m_innerCell->ContainsRect(rect))
     m_innerCell->SelectRect(rect, first, last);
 
-  if (*first == NULL || *last == NULL) {
+  if (*first == NULL || *last == NULL)
+  {
     *first = this;
     *last = this;
   }
@@ -136,7 +137,8 @@ void AbsCell::SelectInner(wxRect& rect, MathCell **first, MathCell **last)
 
 bool AbsCell::BreakUp()
 {
-  if (!m_isBroken) {
+  if (!m_isBroken)
+  {
     m_isBroken = true;
     m_open->m_nextToDraw = m_innerCell;
     m_innerCell->m_previousToDraw = m_open;
