@@ -1,25 +1,25 @@
-/*
- *  Copyright (C) 2005-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- */
+///
+///  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///
+///  This program is free software; you can redistribute it and/or modify
+///  it under the terms of the GNU General Public License as published by
+///  the Free Software Foundation; either version 2 of the License, or
+///  (at your option) any later version.
+///
+///  This program is distributed in the hope that it will be useful,
+///  but WITHOUT ANY WARRANTY; without even the implied warranty of
+///  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+///  GNU General Public License for more details.
+///
+///
+///  You should have received a copy of the GNU General Public License
+///  along with this program; if not, write to the Free Software
+///  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+///
 
 #include "CellParser.h"
 
+#include <wx/font.h>
 #include <wx/config.h>
 
 CellParser::CellParser(wxDC& dc) : m_dc(dc)
@@ -43,8 +43,7 @@ CellParser::CellParser(wxDC& dc, double scale) : m_dc(dc)
 }
 
 CellParser::~CellParser()
-{
-}
+{}
 
 void CellParser::ReadStyle()
 {
@@ -53,6 +52,12 @@ void CellParser::ReadStyle()
   // Font
   config->Read(wxT("Style/fontname"), &m_fontName);
 
+  // Encogind - used only for comments
+  m_fontEncoding = wxFONTENCODING_DEFAULT;
+  int encoding = m_fontEncoding;
+  config->Read(wxT("fontEncoding"), &encoding);
+  m_fontEncoding = (wxFontEncoding)encoding;
+
   // Symbol font
   m_haveSymbolFont = false;
   m_symbolFontAdj = 0;
@@ -215,18 +220,18 @@ void CellParser::ReadStyle()
                &m_styles[10].underlined);
 
   // Highlight
-  m_styles[10].color = m_styles[0].color;
+  m_styles[11].color = m_styles[0].color;
   config->Read(wxT("Style/Highlight/color"),
                &m_styles[11].color);
 
   m_dc.SetPen(*(wxThePenList->FindOrCreatePen(m_styles[0].color, 1, wxSOLID)));
 }
 
-int CellParser::IsBold(int st)
+wxFontWeight CellParser::IsBold(int st)
 {
   if (m_styles[st].bold)
-    return wxBOLD;
-  return wxNORMAL;
+    return wxFONTWEIGHT_BOLD;
+  return wxFONTWEIGHT_NORMAL;
 }
 
 int CellParser::IsItalic(int st)
@@ -243,15 +248,24 @@ int CellParser::IsUnderlined(int st)
   return 0;
 }
 
-wxFontEncoding CellParser::GetSymbolFontEncoding()
+wxString CellParser::GetSymbolFontName()
 {
-#if defined __WXGTK20__
+#if defined __WXMSW__
+  return wxT("Symbol");
+#else
+  return GetFontName();
+#endif
+}
+
+wxFontEncoding CellParser::GetGreekFontEncoding()
+{
+#if defined (__WXGTK20__) || defined (__WXMAC__)
   return wxFONTENCODING_DEFAULT;
 #else
  #if defined __WXMSW__
-    return wxFONTENCODING_CP1253;
+  return wxFONTENCODING_CP1253;
  #else
-    return wxFONTENCODING_ISO8859_7;
+  return wxFONTENCODING_ISO8859_7;
  #endif
 #endif
 }
