@@ -1,62 +1,64 @@
-/*
- *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- */
+///
+///  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///
+///  This program is free software; you can redistribute it and/or modify
+///  it under the terms of the GNU General Public License as published by
+///  the Free Software Foundation; either version 2 of the License, or
+///  (at your option) any later version.
+///
+///  This program is distributed in the hope that it will be useful,
+///  but WITHOUT ANY WARRANTY; without even the implied warranty of
+///  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+///  GNU General Public License for more details.
+///
+///
+///  You should have received a copy of the GNU General Public License
+///  along with this program; if not, write to the Free Software
+///  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+///
 
 #include "Config.h"
 
 #include <wx/config.h>
-#include <wx/fontenum.h>
+#include <wx/font.h>
 #include <wx/fontdlg.h>
 
 // Should match whatever  is put in the m_language
 const int langs[] =
-{
-  wxLANGUAGE_DEFAULT,
-  wxLANGUAGE_ENGLISH,
-  wxLANGUAGE_FRENCH,
-  wxLANGUAGE_GERMAN,
-  wxLANGUAGE_ITALIAN,
-  wxLANGUAGE_SPANISH
-};
+  {
+    wxLANGUAGE_DEFAULT,
+    wxLANGUAGE_ENGLISH,
+    wxLANGUAGE_FRENCH,
+    wxLANGUAGE_GERMAN,
+    wxLANGUAGE_ITALIAN,
+    wxLANGUAGE_PORTUGUESE_BRAZILIAN,
+    wxLANGUAGE_RUSSIAN,
+    wxLANGUAGE_SPANISH
+  };
 
-#define LANGUAGE_NUMBER 6
+#define LANGUAGE_NUMBER 8
 
-const wxString colorlist[] = {
-  wxT("aquamarine"), wxT("black"), wxT("blue"), wxT("blue violet"),
-  wxT("brown"),  wxT("cadet blue"),  wxT("coral"), wxT("cornflower blue"),
-  wxT("cyan"), wxT("dark grey"), wxT("dark green"), wxT("dark olive green"),
-  wxT("dark orchid"), wxT("dark slate blue"), wxT("dark slate grey"),
-  wxT("dark turquoise"), wxT("dim grey"), wxT("firebrick"), wxT("forest green"),
-  wxT("gold"), wxT("goldenrod"), wxT("grey"), wxT("green"), wxT("green yellow"),
-  wxT("indian red"), wxT("khaki"), wxT("light blue"), wxT("light grey"),
-  wxT("light steel blue"), wxT("lime green"), wxT("magenta"), wxT("maroon"),
-  wxT("medium aquamarine"), wxT("medium blue"), wxT("medium forrest green"),
-  wxT("medium goldenrod"), wxT("medium orchid"), wxT("medium sea green"),
-  wxT("medium slate blue"), wxT("medium spring green"), wxT("medium turquoise"),
-  wxT("medium violet red"), wxT("midnight blue"), wxT("navy"), wxT("orange"),
-  wxT("orange red"), wxT("orchid"), wxT("pale green"), wxT("pink"), wxT("plum"),
-  wxT("purple"), wxT("red"), wxT("salmon"), wxT("sea green"), wxT("sienna"),
-  wxT("sky blue"), wxT("slate blue"), wxT("spring green"), wxT("steel blue"),
-  wxT("tan"), wxT("thistle"), wxT("turquoise"), wxT("violet"),
-  wxT("violet red"), wxT("wheat"), wxT("white"), wxT("yellow"),
-  wxT("yellow green")
-};
+const wxString colorlist[] =
+  {
+    wxT("aquamarine"), wxT("black"), wxT("blue"), wxT("blue violet"),
+    wxT("brown"), wxT("cadet blue"), wxT("coral"), wxT("cornflower blue"),
+    wxT("cyan"), wxT("dark grey"), wxT("dark green"), wxT("dark olive green"),
+    wxT("dark orchid"), wxT("dark slate blue"), wxT("dark slate grey"),
+    wxT("dark turquoise"), wxT("dim grey"), wxT("firebrick"), wxT("forest green"),
+    wxT("gold"), wxT("goldenrod"), wxT("grey"), wxT("green"), wxT("green yellow"),
+    wxT("indian red"), wxT("khaki"), wxT("light blue"), wxT("light grey"),
+    wxT("light steel blue"), wxT("lime green"), wxT("magenta"), wxT("maroon"),
+    wxT("medium aquamarine"), wxT("medium blue"), wxT("medium forrest green"),
+    wxT("medium goldenrod"), wxT("medium orchid"), wxT("medium sea green"),
+    wxT("medium slate blue"), wxT("medium spring green"), wxT("medium turquoise"),
+    wxT("medium violet red"), wxT("midnight blue"), wxT("navy"), wxT("orange"),
+    wxT("orange red"), wxT("orchid"), wxT("pale green"), wxT("pink"), wxT("plum"),
+    wxT("purple"), wxT("red"), wxT("salmon"), wxT("sea green"), wxT("sienna"),
+    wxT("sky blue"), wxT("slate blue"), wxT("spring green"), wxT("steel blue"),
+    wxT("tan"), wxT("thistle"), wxT("turquoise"), wxT("violet"),
+    wxT("violet red"), wxT("wheat"), wxT("white"), wxT("yellow"),
+    wxT("yellow green")
+  };
 
 #define COLORLIST_LENGTH 68
 
@@ -80,60 +82,62 @@ Config::Config(wxWindow* parent, int id, const wxString& title,
   label_6 = new wxStaticText(notebook_1_pane_1, -1, _("Additional parameters:"));
   m_additionalParameters = new wxTextCtrl(notebook_1_pane_1, -1, wxEmptyString, wxDefaultPosition, wxSize(250, -1), wxTE_RICH);
   label_4 = new wxStaticText(notebook_1_pane_1, -1, _("Language:"));
-  const wxString m_language_choices[] = {
-    _("(Use default language)"), _("English"),
-    _("French"),  _("German"), _("Italian"), _("Spanish")
-  };
-  m_language = new wxComboBox(notebook_1_pane_1, language_id, wxEmptyString, wxDefaultPosition, wxSize(230, -1), 6, m_language_choices, wxCB_DROPDOWN|wxCB_READONLY);
+  const wxString m_language_choices[] =
+    {
+      _("(Use default language)"), _("English"),
+      _("French"), _("German"), _("Italian"), _("Portuguese (Brazilian)"),
+      _("Russian"), _("Spanish")
+    };
+  m_language = new wxComboBox(notebook_1_pane_1, language_id, wxEmptyString, wxDefaultPosition, wxSize(230, -1), LANGUAGE_NUMBER, m_language_choices, wxCB_DROPDOWN | wxCB_READONLY);
   label_9 = new wxStaticText(notebook_1_pane_1, -1, _("Button panel:"));
-  const wxString m_panelSize_choices[] = {
-    _("Off"), _("Basic"), _("Full")
-  };
-  m_panelSize = new wxComboBox(notebook_1_pane_1, panel_size, wxEmptyString, wxDefaultPosition, wxSize(230, -1), 3, m_panelSize_choices, wxCB_DROPDOWN|wxCB_READONLY);
+  const wxString m_panelSize_choices[] =
+    {
+      _("Off"), _("Basic"), _("Full")
+    };
+  m_panelSize = new wxComboBox(notebook_1_pane_1, panel_size, wxEmptyString, wxDefaultPosition, wxSize(230, -1), 3, m_panelSize_choices, wxCB_DROPDOWN | wxCB_READONLY);
   m_saveSize = new wxCheckBox(notebook_1_pane_1, -1, _("Save wxMaxima window size/position"));
   m_matchParens = new wxCheckBox(notebook_1_pane_1, -1, _("Match parenthesis in text controls"));
   m_fixedFontInTC = new wxCheckBox(notebook_1_pane_1, -1, _("Fixed font in text controls"));
   m_showLong = new wxCheckBox(notebook_1_pane_1, -1, _("Show long expressions"));
   m_showHeader = new wxCheckBox(notebook_1_pane_1, -1, _("Show maxima header"));
+  m_unixCopy = new wxCheckBox(notebook_1_pane_1, -1, _("Copy selection on select"));
   label_7 = new wxStaticText(notebook_1_pane_2, -1, _("Font size:"));
   m_fontSize = new wxSpinCtrl(notebook_1_pane_2, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, 0, 100);
   label_8 = new wxStaticText(notebook_1_pane_2, -1, _("Font family:"));
-  const wxString m_fontFamily_choices[] = {
-
-  };
-  m_fontFamily = new wxComboBox(notebook_1_pane_2, font_family, wxEmptyString, wxDefaultPosition, wxSize(230, -1), 0, m_fontFamily_choices, wxCB_DROPDOWN|wxCB_READONLY|wxCB_SORT);
-  SetupFontList();
+  m_getFont = new wxButton(notebook_1_pane_2, font_family, _("Choose font"), wxDefaultPosition, wxSize(250, -1));
   m_symbolFontOk = new wxCheckBox(notebook_1_pane_2, checkbox_symbol, _("Use greek font"));
   m_getSymbolFont = new wxButton(notebook_1_pane_2, button_symbol, _("Choose font"), wxDefaultPosition, wxSize(250, -1));
   label_10 = new wxStaticText(notebook_1_pane_2, -1, _("Adjustment:"));
   m_symbolFontAdj = new wxSpinCtrl(notebook_1_pane_2, -1, wxEmptyString, wxDefaultPosition, wxDefaultSize, wxSP_ARROW_KEYS, -4, 4);
-  const wxString m_styleFor_choices[] = {
-    _("Variables"), _("Numbers"),  _("Special constants"), _("Greek constants"),
-    _("Strings"), _("Text"), _("Input"), _("Main prompts"),
-    _("Other prompts"), _("Labels"), _("Hidden groups"), _("Highlight"), _("Background")
+  const wxString m_styleFor_choices[] =
+    {
+      _("Variables"), _("Numbers"), _("Special constants"), _("Greek constants"),
+      _("Strings"), _("Text"), _("Input"), _("Main prompts"),
+      _("Other prompts"), _("Labels"), _("Hidden groups"), _("Highlight"), _("Background")
 
-  };
-  m_styleFor = new wxComboBox(notebook_1_pane_2, combobox_styleFor, wxEmptyString, wxDefaultPosition, wxSize(150, -1), 13, m_styleFor_choices, wxCB_DROPDOWN|wxCB_READONLY);
-  const wxString m_styleColor_choices[] = {
-    _("aquamarine"), _("black"), _("blue"), _("blue violet"),
-    _("brown"), _("cadet blue"), _("coral"), _("cornflower blue"),
-    _("cyan"), _("dark grey"), _("dark green"), _("dark olive green"),
-    _("dark orchid"), _("dark slate blue"), _("dark slate grey"),
-    _("dark turquoise"), _("dim grey"), _("firebrick"), _("forest green"),
-    _("gold"), _("goldenrod"), _("grey"), _("green"), _("green yellow"),
-    _("indian red"), _("khaki"), _("light blue"), _("light grey"),
-    _("light steel blue"), _("lime green"), _("magenta"), _("maroon"),
-    _("medium aquamarine"), _("medium blue"), _("medium forrest green"),
-    _("medium goldenrod"), _("medium orchid"), _("medium sea green"),
-    _("medium slate blue"), _("medium spring green"), _("medium turquoise"),
-    _("medium violet red"), _("midnight blue"), _("navy"), _("orange"),
-    _("orange red"), _("orchid"), _("pale green"), _("pink"), _("plum"),
-    _("purple"), _("red"), _("salmon"), _("sea green"), _("sienna"),
-    _("sky blue"), _("slate blue"), _("spring green"), _("steel blue"),
-    _("tan"), _("thistle"), _("turquoise"), _("violet"), _("violet red"),
-    _("wheat"), _("white"), _("yellow"), _("yellow green")
-  };
-  m_styleColor = new wxComboBox(notebook_1_pane_2, combobox_colour, wxEmptyString, wxDefaultPosition, wxSize(150, -1), 68, m_styleColor_choices, wxCB_DROPDOWN|wxCB_READONLY);
+    };
+  m_styleFor = new wxComboBox(notebook_1_pane_2, combobox_styleFor, wxEmptyString, wxDefaultPosition, wxSize(150, -1), 13, m_styleFor_choices, wxCB_DROPDOWN | wxCB_READONLY);
+  const wxString m_styleColor_choices[] =
+    {
+      _("aquamarine"), _("black"), _("blue"), _("blue violet"),
+      _("brown"), _("cadet blue"), _("coral"), _("cornflower blue"),
+      _("cyan"), _("dark grey"), _("dark green"), _("dark olive green"),
+      _("dark orchid"), _("dark slate blue"), _("dark slate grey"),
+      _("dark turquoise"), _("dim grey"), _("firebrick"), _("forest green"),
+      _("gold"), _("goldenrod"), _("grey"), _("green"), _("green yellow"),
+      _("indian red"), _("khaki"), _("light blue"), _("light grey"),
+      _("light steel blue"), _("lime green"), _("magenta"), _("maroon"),
+      _("medium aquamarine"), _("medium blue"), _("medium forrest green"),
+      _("medium goldenrod"), _("medium orchid"), _("medium sea green"),
+      _("medium slate blue"), _("medium spring green"), _("medium turquoise"),
+      _("medium violet red"), _("midnight blue"), _("navy"), _("orange"),
+      _("orange red"), _("orchid"), _("pale green"), _("pink"), _("plum"),
+      _("purple"), _("red"), _("salmon"), _("sea green"), _("sienna"),
+      _("sky blue"), _("slate blue"), _("spring green"), _("steel blue"),
+      _("tan"), _("thistle"), _("turquoise"), _("violet"), _("violet red"),
+      _("wheat"), _("white"), _("yellow"), _("yellow green")
+    };
+  m_styleColor = new wxComboBox(notebook_1_pane_2, combobox_colour, wxEmptyString, wxDefaultPosition, wxSize(150, -1), 68, m_styleColor_choices, wxCB_DROPDOWN | wxCB_READONLY);
   m_boldCB = new wxCheckBox(notebook_1_pane_2, checkbox_bold, _("Bold"));
   m_italicCB = new wxCheckBox(notebook_1_pane_2, checkbox_italic, _("Italic"));
   m_underlinedCB = new wxCheckBox(notebook_1_pane_2, checkbox_underlined, _("Underlined"));
@@ -171,56 +175,78 @@ void Config::set_properties()
   m_showHeader->SetToolTip(_("Show initial header with maxima system information."));
   m_fixedFontInTC->SetToolTip(_("Set fixed font in text controls."));
   m_fixedFontInTC->SetToolTip(_("Set fixed font in text controls."));
-  m_fontFamily->SetToolTip(_("Font used for display in console."));
+  m_getFont->SetToolTip(_("Font used for display in console."));
   m_symbolFontOk->SetToolTip(_("Use greek font to display greek characters."));
   m_symbolFontAdj->SetToolTip(_("Adjustment for the size of greek font."));
+  m_unixCopy->SetToolTip(_("Copy selection to clipboard when selection is made in console."));
 
   wxConfig *config = (wxConfig *)wxConfig::Get();
-  wxString mp, mc, ib, br, mf;
+  wxString mp, mc, ib, mf;
   int fntsz = 12;
-  bool match = true, showLongExpr = false;
+  bool match = true, showLongExpr = false, unixCopy = false;
   bool showHeader = true, fixedFontTC = true;
-  int rs=0;
+  int rs = 0;
   int lang = wxLANGUAGE_UNKNOWN;
   int panelSize = 1;
+  wxString fontEncoding(_("Default"));
 
   m_fontSize->SetRange(8, 20);
   config->Read(wxT("maxima"), &mp);
   config->Read(wxT("parameters"), &mc);
-  config->Read(wxT("browser"), &br);
   config->Read(wxT("pos-restore"), &rs);
   config->Read(wxT("matchParens"), &match);
   config->Read(wxT("fontsize"), &fntsz);
   config->Read(wxT("showLong"), &showLongExpr);
   config->Read(wxT("language"), &lang);
   config->Read(wxT("showHeader"), &showHeader);
+  config->Read(wxT("unixCopy"), &unixCopy);
   config->Read(wxT("fixedFontTC"), &fixedFontTC);
   config->Read(wxT("panelSize"), &panelSize);
+  config->Read(wxT("fontEncoding"), &fontEncoding);
 
-  int i=0;
-  for (i=0; i<LANGUAGE_NUMBER; i++)
+  int i = 0;
+  for (i = 0; i < LANGUAGE_NUMBER; i++)
     if (langs[i] == lang)
       break;
-  if (i<LANGUAGE_NUMBER)
+  if (i < LANGUAGE_NUMBER)
     m_language->SetSelection(i);
   else
     m_language->SetSelection(0);
 
   m_panelSize->SetSelection(panelSize);
 
+#if defined __WXMSW__
+  wxString cwd = wxGetCwd();
+  cwd.Replace(wxT("wxMaxima"), wxT("\\bin\\maxima.bat"));
+  if (wxFileExists(cwd))
+  {
+    m_maximaProgram->SetValue(cwd);
+    m_maximaProgram->Enable(false);
+    m_mpBrowse->Enable(false);
+  }
+  else
+  {
+    if (mp.Length())
+      m_maximaProgram->SetValue(mp);
+    else
+      m_maximaProgram->SetValue(wxT("maxima.bat"));
+  }
+#else
   if (mp.Length())
     m_maximaProgram->SetValue(mp);
   else
     m_maximaProgram->SetValue(wxT("maxima"));
+#endif
   m_additionalParameters->SetValue(mc);
   m_fontSize->SetValue(fntsz);
-  if (rs==1)
+  if (rs == 1)
     m_saveSize->SetValue(true);
   else
     m_saveSize->SetValue(false);
   m_matchParens->SetValue(match);
   m_showLong->SetValue(showLongExpr);
   m_showHeader->SetValue(showHeader);
+  m_unixCopy->SetValue(unixCopy);
   m_fixedFontInTC->SetValue(fixedFontTC);
 
 #if defined __WXMSW__
@@ -228,6 +254,7 @@ void Config::set_properties()
 #else
   m_button2->SetDefault();
 #endif
+
   ReadStyles();
 }
 
@@ -253,33 +280,32 @@ void Config::do_layout()
   wxBoxSizer* sizer_5 = new wxBoxSizer(wxHORIZONTAL);
 
   // Title
-  sizer_1->Add(label_1, 0, wxALL|wxALIGN_CENTER_HORIZONTAL, 3);
+  sizer_1->Add(label_1, 0, wxALL | wxALIGN_CENTER_HORIZONTAL, 3);
 
   // TAB 1
   // Maxima options box
-  grid_sizer_2->Add(label_5, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_2->Add(m_maximaProgram, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_2->Add(m_mpBrowse, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_2->Add(label_6, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_2->Add(label_5, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_2->Add(m_maximaProgram, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_2->Add(m_mpBrowse, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_2->Add(label_6, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
   grid_sizer_2->Add(m_additionalParameters, 0, wxALL, 3);
-  sizer_4->Add(grid_sizer_2, 1, wxALL|wxEXPAND, 3);
-  sizer_3->Add(sizer_4, 1, wxALL|wxEXPAND, 3);
+  sizer_4->Add(grid_sizer_2, 1, wxALL | wxEXPAND, 3);
+  sizer_3->Add(sizer_4, 1, wxALL | wxEXPAND, 3);
 
-  // TAB 2
   // wxMaxima options box
-  grid_sizer_5->Add(label_4, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_5->Add(m_language, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_5->Add(label_9, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_5->Add(m_panelSize, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_5->Add(label_4, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_5->Add(m_language, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_5->Add(label_9, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_5->Add(m_panelSize, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
   sizer_6->Add(grid_sizer_5, 1, wxEXPAND, 0);
   sizer_6->Add(m_saveSize, 0, wxALL, 3);
   sizer_6->Add(m_matchParens, 0, wxALL, 3);
   sizer_6->Add(m_fixedFontInTC, 0, wxALL, 3);
   sizer_6->Add(m_showLong, 0, wxALL, 3);
   sizer_6->Add(m_showHeader, 0, wxALL, 3);
-  sizer_3->Add(sizer_6, 1, wxALL|wxEXPAND, 3);
+  sizer_6->Add(m_unixCopy, 0, wxALL, 3);
+  sizer_3->Add(sizer_6, 1, wxALL | wxEXPAND, 3);
 
-  // Tab 1
   notebook_1_pane_1->SetAutoLayout(true);
   notebook_1_pane_1->SetSizer(sizer_3);
   sizer_3->Fit(notebook_1_pane_1);
@@ -288,33 +314,33 @@ void Config::do_layout()
 
   // TAB 2
   // Font box
-  grid_sizer_1->Add(label_7, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_1->Add(m_fontSize, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_1->Add(label_8, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_1->Add(m_fontFamily, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  sizer_9->Add(grid_sizer_1, 1, wxALL|wxEXPAND, 3);
-  sizer_8->Add(sizer_9, 1, wxALL|wxEXPAND, 3);
+  grid_sizer_1->Add(label_7, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_1->Add(m_fontSize, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_1->Add(label_8, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_1->Add(m_getFont, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  sizer_9->Add(grid_sizer_1, 1, wxALL | wxEXPAND, 3);
+  sizer_8->Add(sizer_9, 1, wxALL | wxEXPAND, 3);
 
   // Greek font box
-  grid_sizer_3->Add(m_symbolFontOk, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_3->Add(m_getSymbolFont, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_3->Add(label_10, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_3->Add(m_symbolFontAdj, 0, wxALL|wxALIGN_CENTER_VERTICAL, 5);
-  sizer_12->Add(grid_sizer_3, 1, wxALL|wxEXPAND, 3);
-  sizer_8->Add(sizer_12, 1, wxALL|wxEXPAND, 3);
+  grid_sizer_3->Add(m_symbolFontOk, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_3->Add(m_getSymbolFont, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_3->Add(label_10, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_3->Add(m_symbolFontAdj, 0, wxALL | wxALIGN_CENTER_VERTICAL, 5);
+  sizer_12->Add(grid_sizer_3, 1, wxALL | wxEXPAND, 3);
+  sizer_8->Add(sizer_12, 1, wxALL | wxEXPAND, 3);
 
   // Styles box
-  grid_sizer_4->Add(m_styleFor, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_4->Add(m_styleFor, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
   grid_sizer_4->Add(20, 20, 0, wxALL, 0);
-  grid_sizer_4->Add(m_styleColor, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  sizer_5->Add(m_boldCB, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  sizer_5->Add(m_italicCB, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  sizer_5->Add(m_underlinedCB, 0, wxALL|wxALIGN_CENTER_VERTICAL, 3);
-  grid_sizer_4->Add(sizer_5, 1, wxALL|wxEXPAND, 3);
+  grid_sizer_4->Add(m_styleColor, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  sizer_5->Add(m_boldCB, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  sizer_5->Add(m_italicCB, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  sizer_5->Add(m_underlinedCB, 0, wxALL | wxALIGN_CENTER_VERTICAL, 3);
+  grid_sizer_4->Add(sizer_5, 1, wxALL | wxEXPAND, 3);
   grid_sizer_4->Add(20, 20, 0, wxALL, 0);
-  grid_sizer_4->Add(label_11, 0, wxALL|wxEXPAND, 3);
-  sizer_11->Add(grid_sizer_4, 1, wxALL|wxEXPAND, 3);
-  sizer_8->Add(sizer_11, 1, wxALL|wxEXPAND, 3);
+  grid_sizer_4->Add(label_11, 0, wxALL | wxEXPAND, 3);
+  sizer_11->Add(grid_sizer_4, 1, wxALL | wxEXPAND, 3);
+  sizer_8->Add(sizer_11, 1, wxALL | wxEXPAND, 3);
 
   // Tab 2
   notebook_1_pane_2->SetAutoLayout(true);
@@ -328,16 +354,12 @@ void Config::do_layout()
   notebook_1->AddPage(notebook_1_pane_2, _("Style"));
 
   // Add notebook to dialog
-#if wxCHECK_VERSION(2,5,3)
-  sizer_1->Add(notebook_1, 1, wxEXPAND|wxALL, 2);
-#else
-  sizer_1->Add(new wxNotebookSizer(notebook_1), 1, wxEXPAND|wxALL, 2);
-#endif
+  sizer_1->Add(notebook_1, 1, wxEXPAND | wxALL, 2);
 
   // OK and cancel buttons
-  sizer_2->Add(m_button1, 0, wxLEFT|wxRIGHT, 5);
-  sizer_2->Add(m_button2, 0, wxLEFT|wxRIGHT, 5);
-  sizer_1->Add(sizer_2, 1, wxALIGN_RIGHT|wxTOP|wxBOTTOM, 3);
+  sizer_2->Add(m_button1, 0, wxLEFT | wxRIGHT, 5);
+  sizer_2->Add(m_button2, 0, wxLEFT | wxRIGHT, 5);
+  sizer_1->Add(sizer_2, 1, wxALIGN_RIGHT | wxTOP | wxBOTTOM, 3);
 
   SetAutoLayout(true);
   SetSizer(sizer_1);
@@ -351,7 +373,7 @@ void Config::do_layout()
 
 void Config::OnOk(wxCommandEvent& event)
 {
-  int i=0;
+  int i = 0;
   wxString search = wxT("maxima-htmldir");
   wxArrayString out;
   wxString maxima = m_maximaProgram->GetValue();
@@ -363,15 +385,18 @@ void Config::OnOk(wxCommandEvent& event)
   config->Write(wxT("showLong"), m_showLong->GetValue());
   config->Write(wxT("showHeader"), m_showHeader->GetValue());
   config->Write(wxT("fixedFontTC"), m_fixedFontInTC->GetValue());
+  config->Write(wxT("unixCopy"), m_unixCopy->GetValue());
   config->Write(wxT("panelSize"), m_panelSize->GetSelection());
   if (m_saveSize->GetValue())
     config->Write(wxT("pos-restore"), 1);
   else
     config->Write(wxT("pos-restore"), 0);
   i = m_language->GetSelection();
-  if (i>-1 && i<LANGUAGE_NUMBER) {
+  if (i > -1 && i < LANGUAGE_NUMBER)
+  {
     config->Write(wxT("language"), langs[i]);
   }
+
   config->Flush();
 
   WriteStyles();
@@ -394,7 +419,9 @@ void Config::OnMpBrowse(wxCommandEvent& event)
                                  wxEmptyString, _("All|*"),
                                  wxOPEN);
 #endif
-  if (file.Length()) {
+
+  if (file.Length())
+  {
     m_maximaProgram->SetValue(file);
   }
 }
@@ -411,7 +438,9 @@ void Config::OnSymbolBrowse(wxCommandEvent& event)
                                           false, m_symbolFontName,
                                           wxFONTENCODING_ISO8859_7));
 #endif
-  if (symbol.Ok()) {
+
+  if (symbol.Ok())
+  {
     m_symbolFontName = symbol.GetFaceName();
     m_getSymbolFont->SetLabel(m_symbolFontName);
   }
@@ -419,19 +448,35 @@ void Config::OnSymbolBrowse(wxCommandEvent& event)
 
 void Config::OnChangeFontFamily(wxCommandEvent& event)
 {
-  UpdateExample();
+  wxFont font;
+  font = wxGetFontFromUser(this, wxFont(m_fontSize->GetValue(),
+                                        wxNORMAL, wxNORMAL, wxNORMAL,
+                                        false, m_fontFamily,
+                                        m_fontEncoding));
+  if (font.Ok())
+  {
+    m_fontFamily = font.GetFaceName();
+    m_getFont->SetLabel(m_fontFamily);
+    m_fontEncoding = font.GetEncoding();
+    m_fontSize->SetValue(font.GetPointSize());
+    UpdateExample();
+  }
 }
 
 void Config::ReadStyles()
 {
   wxConfigBase* config = wxConfig::Get();
 
-  wxString font;
   int adj = 0;
   bool symbolOk = false;
 
-  config->Read(wxT("Style/fontname"), &font);
-  m_fontFamily->SetValue(font);
+  config->Read(wxT("Style/fontname"), &m_fontFamily);
+  if (m_fontFamily.Length())
+    m_getFont->SetLabel(m_fontFamily);
+
+  int encoding = m_fontEncoding;
+  config->Read(wxT("fontEncoding"), &encoding);
+  m_fontEncoding = (wxFontEncoding)encoding;
 
   m_symbolFontName = wxEmptyString;
   config->Read(wxT("Style/Symbol/ok"), &symbolOk);
@@ -439,7 +484,7 @@ void Config::ReadStyles()
   config->Read(wxT("Style/Symbol/adj"), &adj);
   m_symbolFontAdj->SetValue(adj);
   m_symbolFontOk->SetValue(symbolOk);
-  if (m_symbolFontName.Length()>0)
+  if (m_symbolFontName.Length() > 0)
     m_getSymbolFont->SetLabel(m_symbolFontName);
   m_getSymbolFont->Enable(symbolOk);
   m_symbolFontAdj->Enable(symbolOk);
@@ -605,8 +650,8 @@ void Config::ReadStyles()
 
   // Set values in dialog
   m_styleFor->SetSelection(0);
-  int i=0;
-  for (i=0; i<COLORLIST_LENGTH; i++)
+  int i = 0;
+  for (i = 0; i < COLORLIST_LENGTH; i++)
     if (m_styleNormalText.color == colorlist[i])
       break;
   m_styleColor->SetSelection(i);
@@ -624,7 +669,8 @@ void Config::WriteStyles()
   config->Write(wxT("Style/Highlight/color"),
                 m_styleHighlight.color);
 
-  config->Write(wxT("Style/fontname"), m_fontFamily->GetValue());
+  config->Write(wxT("Style/fontname"), m_fontFamily);
+  config->Write(wxT("fontEncoding"), m_fontEncoding);
 
   config->Write(wxT("Style/Symbol/ok"), m_symbolFontOk->GetValue());
   config->Write(wxT("Style/Symbol/fontname"), m_symbolFontName);
@@ -743,7 +789,7 @@ void Config::WriteStyles()
 
 void Config::OnChangeColor(wxCommandEvent& event)
 {
-  style* tmp =GetStylePointer();
+  style* tmp = GetStylePointer();
 
   int i = m_styleColor->GetSelection();
   tmp->color = colorlist[i];
@@ -756,25 +802,29 @@ void Config::OnChangeStyle(wxCommandEvent& event)
   style* tmp = GetStylePointer();
   int st = m_styleFor->GetSelection();
 
-  if (tmp == &m_styleHiddenText) {
+  if (tmp == &m_styleHiddenText)
+  {
     m_styleColor->Enable(false);
   }
-  else {
+  else
+  {
     m_styleColor->Enable(true);
-    int i=0;
-    for (i=0; i<COLORLIST_LENGTH; i++)
+    int i = 0;
+    for (i = 0; i < COLORLIST_LENGTH; i++)
       if (colorlist[i] == tmp->color)
         break;
-    if (i<COLORLIST_LENGTH)
+    if (i < COLORLIST_LENGTH)
       m_styleColor->SetSelection(i);
   }
 
-  if (st == 11 || st == 12) {
+  if (st == 11 || st == 12)
+  {
     m_boldCB->Enable(false);
     m_italicCB->Enable(false);
     m_underlinedCB->Enable(false);
   }
-  else {
+  else
+  {
     m_boldCB->Enable(true);
     m_italicCB->Enable(true);
     m_underlinedCB->Enable(true);
@@ -802,30 +852,6 @@ void Config::OnCheckSymbol(wxCommandEvent& event)
   m_symbolFontAdj->Enable(m_symbolFontOk->GetValue());
 }
 
-class FixedFonts : public wxFontEnumerator
-{
-public:
-  const wxArrayString& GetFacenames() { return m_facenames; }
-protected:
-  virtual bool OnFacename(const wxString& facename)
-  {
-    m_facenames.Add(facename);
-    return true;
-  }
-private:
-   wxArrayString m_facenames;
-};
-
-void Config::SetupFontList()
-{
-  FixedFonts enumerator;
-  enumerator.EnumerateFacenames(wxFONTENCODING_SYSTEM, true);
-
-  const wxArrayString& strings = enumerator.GetFacenames();
-  for (unsigned int i=0; i<strings.Count(); i++)
-    m_fontFamily->Append(strings.Item(i));
-}
-
 void Config::OnChangeWarning(wxCommandEvent &event)
 {
   wxMessageBox(_("Please restart wxMaxima for changes to take effect!"),
@@ -841,45 +867,45 @@ style* Config::GetStylePointer()
   style* tmp = &m_styleNormalText;
   switch (m_styleFor->GetSelection())
   {
-    case 1:
-      tmp = &m_styleNumber;
-      break;
-    case 2:
-      tmp = &m_styleSpecial;
-      break;
-    case 3:
-      tmp = &m_styleGreek;
-      break;
-    case 4:
-      tmp = &m_styleString;
-      break;
-    case 5:
-      tmp = &m_styleNormalText;
-      break;
-    case 6:
-      tmp = &m_styleInput;
-      break;
-    case 7:
-      tmp = &m_styleMainPrompt;
-      break;
-    case 8:
-      tmp = &m_styleOtherPrompt;
-      break;
-    case 9:
-      tmp = &m_styleLabel;
-      break;
-    case 10:
-      tmp = &m_styleHiddenText;
-      break;
-    case 11:
-      tmp = &m_styleHighlight;
-      break;
-    case 12:
-      tmp = &m_styleBackground;
-      break;
-    default:
-      tmp = &m_styleVariable;
-      break;
+  case 1:
+    tmp = &m_styleNumber;
+    break;
+  case 2:
+    tmp = &m_styleSpecial;
+    break;
+  case 3:
+    tmp = &m_styleGreek;
+    break;
+  case 4:
+    tmp = &m_styleString;
+    break;
+  case 5:
+    tmp = &m_styleNormalText;
+    break;
+  case 6:
+    tmp = &m_styleInput;
+    break;
+  case 7:
+    tmp = &m_styleMainPrompt;
+    break;
+  case 8:
+    tmp = &m_styleOtherPrompt;
+    break;
+  case 9:
+    tmp = &m_styleLabel;
+    break;
+  case 10:
+    tmp = &m_styleHiddenText;
+    break;
+  case 11:
+    tmp = &m_styleHighlight;
+    break;
+  case 12:
+    tmp = &m_styleBackground;
+    break;
+  default:
+    tmp = &m_styleVariable;
+    break;
   }
   return tmp;
 }
@@ -897,12 +923,9 @@ void Config::UpdateExample()
   else if (tmp == &m_styleHiddenText)
     color = m_styleMainPrompt.color;
 
-  label_11->SetStyle(color, tmp->italic, tmp->bold, tmp->underlined, m_fontFamily->GetValue());
-#if wxCHECK_VERSION(2, 5, 3)
+  label_11->SetStyle(color, tmp->italic, tmp->bold, tmp->underlined, m_fontFamily);
   label_11->SetBackgroundColour(wxTheColourDatabase->Find(m_styleBackground.color));
-#else
-  label_11->SetBackgroundColour(*(wxTheColourDatabase->FindColour(m_styleBackground.color)));
-#endif
+
   label_11->Refresh();
 }
 
@@ -910,9 +933,9 @@ BEGIN_EVENT_TABLE(Config, wxDialog)
   EVT_BUTTON(wxID_OK, Config::OnOk)
   EVT_BUTTON(wxID_OPEN, Config::OnMpBrowse)
   EVT_BUTTON(button_symbol, Config::OnSymbolBrowse)
+  EVT_BUTTON(font_family, Config::OnChangeFontFamily)
   EVT_COMBOBOX(combobox_colour, Config::OnChangeColor)
   EVT_COMBOBOX(combobox_styleFor, Config::OnChangeStyle)
-  EVT_COMBOBOX(font_family, Config::OnChangeFontFamily)
   EVT_COMBOBOX(language_id, Config::OnChangeWarning)
   EVT_COMBOBOX(panel_size, Config::OnChangeWarning)
   EVT_CHECKBOX(checkbox_bold, Config::OnCheckbox)
@@ -931,11 +954,7 @@ void ExamplePanel::OnPaint(wxPaintEvent& event)
 
   GetClientSize(&panel_width, &panel_height);
 
-#if wxCHECK_VERSION(2, 5, 3)
   dc.SetTextForeground(wxTheColourDatabase->Find(m_fgColor));
-#else
-  dc.SetTextForeground(*(wxTheColourDatabase->FindColour(m_fgColor)));
-#endif
 
   if (m_bold)
     bold = wxBOLD;
@@ -946,10 +965,11 @@ void ExamplePanel::OnPaint(wxPaintEvent& event)
   dc.SetFont(wxFont(m_size, wxMODERN, italic, bold, underlined, m_font));
   dc.GetTextExtent(example, &text_width, &text_height);
 
-  dc.DrawText(example, (panel_width - text_width)/2,
-                       (panel_height - text_height)/2);
+  dc.DrawText(example, (panel_width - text_width) / 2,
+              (panel_height - text_height) / 2);
 }
 
 BEGIN_EVENT_TABLE(ExamplePanel, wxPanel)
   EVT_PAINT(ExamplePanel::OnPaint)
 END_EVENT_TABLE()
+
