@@ -1,22 +1,21 @@
-/*
- *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- */
+///
+///  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///
+///  This program is free software; you can redistribute it and/or modify
+///  it under the terms of the GNU General Public License as published by
+///  the Free Software Foundation; either version 2 of the License, or
+///  (at your option) any later version.
+///
+///  This program is distributed in the hope that it will be useful,
+///  but WITHOUT ANY WARRANTY; without even the implied warranty of
+///  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+///  GNU General Public License for more details.
+///
+///
+///  You should have received a copy of the GNU General Public License
+///  along with this program; if not, write to the Free Software
+///  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+///
 
 #include "LimitCell.h"
 
@@ -42,11 +41,11 @@ LimitCell::~LimitCell()
 MathCell* LimitCell::Copy(bool all)
 {
   LimitCell* tmp = new LimitCell;
+  CopyData(this, tmp);
   tmp->SetBase(m_base->Copy(true));
   tmp->SetUnder(m_under->Copy(true));
   tmp->SetName(m_name->Copy(true));
-  tmp->m_type = m_type;
-  if (all && m_next!=NULL)
+  if (all && m_next != NULL)
     tmp->AppendCell(m_next->Copy(true));
   return tmp;
 }
@@ -68,7 +67,7 @@ void LimitCell::Destroy()
 void LimitCell::SetName(MathCell* name)
 {
   if (name == NULL)
-    return;
+    return ;
   if (m_name != NULL)
     delete m_name;
   m_name = name;
@@ -77,7 +76,7 @@ void LimitCell::SetName(MathCell* name)
 void LimitCell::SetBase(MathCell* base)
 {
   if (base == NULL)
-    return;
+    return ;
   if (m_base != NULL)
     delete m_base;
   m_base = base;
@@ -86,7 +85,7 @@ void LimitCell::SetBase(MathCell* base)
 void LimitCell::SetUnder(MathCell *under)
 {
   if (under == NULL)
-    return;
+    return ;
   if (m_under != NULL)
     delete m_under;
   m_under = under;
@@ -97,18 +96,18 @@ void LimitCell::RecalculateWidths(CellParser& parser, int fontsize, bool all)
   double scale = parser.GetScale();
 
   m_base->RecalculateWidths(parser, fontsize, true);
-  m_under->RecalculateWidths(parser, MAX(7, fontsize-5), true);
+  m_under->RecalculateWidths(parser, MAX(7, fontsize - 5), true);
   m_name->RecalculateWidths(parser, fontsize, true);
 
   m_width = MAX(m_name->GetFullWidth(scale), m_under->GetFullWidth(scale))
-          + m_base->GetFullWidth(scale);
+            + m_base->GetFullWidth(scale);
 
   MathCell::RecalculateWidths(parser, fontsize, all);
 }
 
 void LimitCell::RecalculateSize(CellParser& parser, int fontsize, bool all)
 {
-  m_under->RecalculateSize(parser, MAX(7, fontsize-5), true);
+  m_under->RecalculateSize(parser, MAX(7, fontsize - 5), true);
   m_name->RecalculateSize(parser, fontsize, true);
   m_base->RecalculateSize(parser, fontsize, true);
 
@@ -121,20 +120,21 @@ void LimitCell::RecalculateSize(CellParser& parser, int fontsize, bool all)
 
 void LimitCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
 {
-  if (DrawThisCell(parser, point)) {
+  if (DrawThisCell(parser, point))
+  {
     double scale = parser.GetScale();
     wxPoint base(point), under(point), name(point);
 
     name.x = point.x + MAX(m_name->GetFullWidth(scale),
-                           m_under->GetFullWidth(scale))/2 -
-                       m_name->GetFullWidth(scale)/2;
+                           m_under->GetFullWidth(scale)) / 2 -
+             m_name->GetFullWidth(scale) / 2;
     m_name->Draw(parser, name, fontsize, true);
 
     under.x = point.x + MAX(m_name->GetFullWidth(scale),
-                            m_under->GetFullWidth(scale))/2 -
-                        m_under->GetFullWidth(scale)/2;
+                            m_under->GetFullWidth(scale)) / 2 -
+              m_under->GetFullWidth(scale) / 2;
     under.y = point.y + m_name->GetMaxDrop() + m_under->GetMaxCenter();
-    m_under->Draw(parser, under, MAX(7, fontsize-5), true);
+    m_under->Draw(parser, under, MAX(7, fontsize - 5), true);
 
     base.x += MAX(m_name->GetFullWidth(scale),
                   m_under->GetFullWidth(scale));
@@ -149,9 +149,9 @@ wxString LimitCell::ToString(bool all)
   wxString s = m_name->ToString(true);
   wxString under = m_under->ToString(true);
   wxString base = m_base->ToString(true);
-  wxString var = under.SubString(0, under.Find(wxT("->"))-1);
-  wxString to = under.SubString(under.Find(wxT("->"))+2,
-                                under.Length()-1);
+  wxString var = under.SubString(0, under.Find(wxT("->")) - 1);
+  wxString to = under.SubString(under.Find(wxT("->")) + 2,
+                                under.Length() - 1);
   s += wxT("(") + base + wxT(",") + var + wxT(",") + to + wxT(")");
   s += MathCell::ToString(all);
   return s;
@@ -163,7 +163,8 @@ void LimitCell::SelectInner(wxRect& rect, MathCell** first, MathCell** last)
   *last = NULL;
   if (m_base->ContainsRect(rect))
     m_base->SelectRect(rect, first, last);
-  if (*first == NULL || *last == NULL) {
+  if (*first == NULL || *last == NULL)
+  {
     *first = this;
     *last = this;
   }
