@@ -1,22 +1,21 @@
-/*
- *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- */
+///
+///  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///
+///  This program is free software; you can redistribute it and/or modify
+///  it under the terms of the GNU General Public License as published by
+///  the Free Software Foundation; either version 2 of the License, or
+///  (at your option) any later version.
+///
+///  This program is distributed in the hope that it will be useful,
+///  but WITHOUT ANY WARRANTY; without even the implied warranty of
+///  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+///  GNU General Public License for more details.
+///
+///
+///  You should have received a copy of the GNU General Public License
+///  along with this program; if not, write to the Free Software
+///  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+///
 
 #include "ParenCell.h"
 #include "TextCell.h"
@@ -43,8 +42,8 @@ ParenCell::~ParenCell()
 MathCell* ParenCell::Copy(bool all)
 {
   ParenCell *tmp = new ParenCell;
+  CopyData(this, tmp);
   tmp->SetInner(m_innerCell->Copy(true), m_type);
-  tmp->m_type = m_type;
   if (all && m_next != NULL)
     tmp->AppendCell(m_next->Copy(all));
   return tmp;
@@ -61,7 +60,7 @@ void ParenCell::Destroy()
 void ParenCell::SetInner(MathCell *inner, int type)
 {
   if (inner == NULL)
-    return;
+    return ;
   if (m_innerCell != NULL)
     delete m_innerCell;
   m_innerCell = inner;
@@ -103,7 +102,8 @@ void ParenCell::RecalculateSize(CellParser& parser, int fontsize, bool all)
 
 void ParenCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
 {
-  if (DrawThisCell(parser, point)) {
+  if (DrawThisCell(parser, point))
+  {
     double scale = parser.GetScale();
     wxDC& dc = parser.GetDC();
     wxPoint in;
@@ -146,13 +146,14 @@ void ParenCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
 wxString ParenCell::ToString(bool all)
 {
   wxString s;
-  if (!m_isBroken) {
+  if (!m_isBroken)
+  {
     if (m_print)
       s = wxT("(") + m_innerCell->ToString(true) + wxT(")");
     else
       s = m_innerCell->ToString(true);
   }
-  s +=  MathCell::ToString(all);
+  s += MathCell::ToString(all);
   return s;
 }
 
@@ -164,7 +165,8 @@ void ParenCell::SelectInner(wxRect& rect, MathCell **first, MathCell **last)
   if (m_innerCell->ContainsRect(rect))
     m_innerCell->SelectRect(rect, first, last);
 
-  if (*first == NULL || *last == NULL) {
+  if (*first == NULL || *last == NULL)
+  {
     *first = this;
     *last = this;
   }
@@ -172,7 +174,8 @@ void ParenCell::SelectInner(wxRect& rect, MathCell **first, MathCell **last)
 
 bool ParenCell::BreakUp()
 {
-  if (!m_isBroken) {
+  if (!m_isBroken)
+  {
     m_isBroken = true;
     m_open->m_nextToDraw = m_innerCell;
     m_innerCell->m_previousToDraw = m_open;
