@@ -1,23 +1,21 @@
-/*
- *  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
- *
- *
- *  You should have received a copy of the GNU General Public License
- *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- */
-
+///
+///  Copyright (C) 2004-2006 Andrej Vodopivec <andrejv@users.sourceforge.net>
+///
+///  This program is free software; you can redistribute it and/or modify
+///  it under the terms of the GNU General Public License as published by
+///  the Free Software Foundation; either version 2 of the License, or
+///  (at your option) any later version.
+///
+///  This program is distributed in the hope that it will be useful,
+///  but WITHOUT ANY WARRANTY; without even the implied warranty of
+///  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+///  GNU General Public License for more details.
+///
+///
+///  You should have received a copy of the GNU General Public License
+///  along with this program; if not, write to the Free Software
+///  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+///
 
 #ifndef PLOT2DWIZ_H
 #define PLOT2DWIZ_H
@@ -29,11 +27,12 @@
 
 #include "BTextCtrl.h"
 
-class Plot2DWiz: public wxDialog {
+class Plot2DWiz: public wxDialog
+{
 public:
   Plot2DWiz(wxWindow* parent, int id, const wxString& title,
-            const wxPoint& pos=wxDefaultPosition,
-            const wxSize& size=wxDefaultSize, long style=wxDEFAULT_DIALOG_STYLE);
+            const wxPoint& pos = wxDefaultPosition,
+            const wxSize& size = wxDefaultSize, long style = wxDEFAULT_DIALOG_STYLE);
   void SetValue(wxString s);
   wxString GetValue();
 private:
@@ -78,12 +77,16 @@ protected:
 };
 
 
-class Plot2dPar: public wxDialog {
+class Plot2dPar: public wxDialog
+{
 public:
   Plot2dPar(wxWindow* parent, int id, const wxString& title,
-            const wxPoint& pos=wxDefaultPosition,
-            const wxSize& size=wxDefaultSize, long style=wxDEFAULT_DIALOG_STYLE);
-  void SetValue(wxString s) { text_ctrl_1->SetValue(s); }
+            const wxPoint& pos = wxDefaultPosition,
+            const wxSize& size = wxDefaultSize, long style = wxDEFAULT_DIALOG_STYLE);
+  void SetValue(wxString s)
+  {
+    text_ctrl_1->SetValue(s);
+  }
   wxString GetValue();
 private:
   void set_properties();
@@ -105,5 +108,4 @@ protected:
   wxButton* button_2;
 };
 
-
 #endif // PLOT2DWIZ_H
